<?php
namespace Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class FornecedorMascara {

    protected $dataSourceName = "fornecedor";
    protected $dataSourceManager;

    public function __construct($dataSourceManager) {
        $this->dataSourceManager = $dataSourceManager;
    }

    public function retornaFornecedoresFormatado(Request\Filter $request, Response $response) {
        try {
            $filterCriteria = $request->getFilterCriteria();
            $filterCriteria->setDataSourceName($this->dataSourceName);

            $dataSource = $this->dataSourceManager->findBy($filterCriteria);

            $dataSet = self::formataMascara($dataSource->getRows(), self::getObjectProviderType());

            $response->addDataSet(new DataSet('fornecedoMascara', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function formataMascara($rows, $object){
        for($i = 0; $i < count($rows); $i ++){
            $type = $rows[$i]['IDTPIJURFORN'];
            $maskInscricao = $object[$type]['mask'];

            if($maskInscricao) {
                for ($j = 0; $j < strlen($rows[$i]['NRINSJURFORN']); $j++) {
                    $maskInscricao[strpos($maskInscricao, "#")] = $rows[$i]['NRINSJURFORN'][$j];
                }

                $rows[$i]['NRINSJURFORN'] = $maskInscricao;
            }
        }

        return $rows;
    }

    public function getObjectProviderType() {

    return
        array(
            "F" => array(
                "name" => "Física",
                "mask" => "###.###.###-##"
            ),
            "J" => array(
                "name" => "Jurídica",
                "mask" => "##.###.###/####-##"
            ),
            "I" => array(
                "name" => "Internacional",
                "mask" => ""
            ),
            "O" => array(
                "name" => "Outros",
                "mask" => ""
            )
        );
    }
}