<?php
namespace Modules\Cotacao\Modules\ListaPreco\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Doctrine\ORM\EntityManager;

class Sup09200AcompanhamentoAtualizacaoCustoListaPreco extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $connection;
    protected $environment;
    public function __construct($crudService, $parameterBag, $connection, $environment) {
        $this->connection  = $connection;
        $this->environment = $environment;
    }
      
    public function verificarLista (DTO\Request $request, DTO\Response $response){
        $row = $request->getDataSet()->getRows();
    	$retorno = $this->queryLista($row);
        $response->addDataSet(new DataSet("resp", $retorno));
    }
    
    public function queryLista($row){
       $query = "SELECT T.CDCENULTLISPREC, T.NRSEQULTLISPREC, R.CDREGIAO, R.NMREGIAO, F.CDFILIAL, F.NMFILIAL, P.CDARVPROD, P.NMPRODUTO, T.QTFILIALLISPREC, T.QTREGIAOLISPREC, T.QTPRODLISPREC, T.NRORG FROM TEMPULTATULISPR T, PRODUTO P, FILIAL F, REGIAO R WHERE T.CDCENULTLISPREC = :P_CDFILIAL AND T.NRSEQULTLISPREC = :P_NRSEQPRELIST AND T.NRORG = :NRORG AND T.CDPRODULLISPREC = P.CDPRODUTO AND T.CDFILULTLISPREC = F.CDFILIAL AND T.CDREGULTLISPREC = R.CDREGIAO";
		 $params = array();
	        $params["P_CDFILIAL"] = $row[0]['CDFILIAL'];
		 	$params["P_NRSEQPRELIST"] = $row[0]['NRSEQPRELIST'];
		 	$params["NRORG"] = $this->environment->getNrorg();
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
	    return $stmt->fetchAll(); 
    }
    
    public function excluirRegistros(DTO\Request $request, DTO\Response $response){
        $row = $request->getDataSet()->getRows();
        $retorno = $this->queryLista($row);
        if(empty($retorno)){
            $erro = new Error("Operação bloqueada! não existem registros a serem deletados!", 500);
            $response->setError($erro);
        }else{
            $this->deleteReg($row);
        }
    }
    
    public function deleteReg ($row){
    	$query = "DELETE FROM TEMPULTATULISPR WHERE CDCENULTLISPREC = :P_CDFILIAL AND NRSEQULTLISPREC = :P_NRSEQPRELIST";
		 $params = array();
	        $params["P_CDFILIAL"] = $row[0]['CDFILIAL'];
		 	$params["P_NRSEQPRELIST"] = $row[0]['NRSEQPRELIST'];
		$stmt = $this->connection->prepare($query);
		$stmt->execute($params);
    }
   
}
    